==> maven-scm-provider-hg-1.1-sources.jar: org/apache/maven/scm/provider/hg/command/remove/HgRemoveConsumer.java <==
package org.apache.maven.scm.provider.hg.command.remove;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import org.apache.maven.scm.ScmFile;
import org.apache.maven.scm.ScmFileStatus;
import org.apache.maven.scm.log.ScmLogger;
import org.apache.maven.scm.provider.hg.command.HgConsumer;

import java.io.File;
import java.util.ArrayList;
import java.util.List;

/**
 * @author <a href="mailto:thurner.rupert@ymono.net">thurner rupert</a>
 * @version $Id: HgRemoveConsumer.java 685548 2008-08-13 13:35:49Z vsiveton $
 */
public class HgRemoveConsumer
    extends HgConsumer
{
    private final File workingDir;

    private final List removedFiles = new ArrayList();

    public HgRemoveConsumer( ScmLogger logger, File workingDir )
    {
        super( logger );
        this.workingDir = workingDir;
    }

    /** {@inheritDoc} */
    public void doConsume( ScmFileStatus status, String trimmedLine )
    {
        if ( status != null && status == ScmFileStatus.DELETED )
        {
            //Only include real files (not directories)
            File tmpFile = new File( workingDir, trimmedLine );
            if ( !tmpFile.exists() )
            {
                getLogger().warn( "Not a file: " + tmpFile + ". Ignored" );
            }
            else
            {
                ScmFile scmFile = new ScmFile( trimmedLine, ScmFileStatus.DELETED );
                getLogger().info( scmFile.toString() );
                removedFiles.add( scmFile );
            }
        }
    }

    public List getRemovedFiles()
    {
        return removedFiles;
    }
}

==> maven-scm-provider-hg-1.7-sources.jar: org/apache/maven/scm/provider/hg/command/remove/HgRemoveConsumer.java <==
package org.apache.maven.scm.provider.hg.command.remove;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import org.apache.maven.scm.ScmFile;
import org.apache.maven.scm.ScmFileStatus;
import org.apache.maven.scm.log.ScmLogger;
import org.apache.maven.scm.provider.hg.command.HgConsumer;

import java.io.File;
import java.util.ArrayList;
import java.util.List;

/**
 * @author <a href="mailto:thurner.rupert@ymono.net">thurner rupert</a>
 * @author Olivier Lamy
 * @version $Id: HgRemoveConsumer.java 1056938 2011-01-09 14:27:54Z olamy $
 */
public class HgRemoveConsumer
    extends HgConsumer
{
    private final File workingDir;

    private final List<ScmFile> removedFiles = new ArrayList<ScmFile>();

    public HgRemoveConsumer( ScmLogger logger, File workingDir )
    {
        super( logger );
        this.workingDir = workingDir;
    }

    /** {@inheritDoc} */
    public void doConsume( ScmFileStatus status, String trimmedLine )
    {
        if ( status != null && status == ScmFileStatus.DELETED )
        {
            //Only include real files (not directories)
            File tmpFile = new File( workingDir, trimmedLine );
            if ( !tmpFile.exists() )
            {
                if ( getLogger().isWarnEnabled() )
                {
                    getLogger().warn( "Not a file: " + tmpFile + ". Ignored" );
                }
            }
            else
            {
                ScmFile scmFile = new ScmFile( trimmedLine, ScmFileStatus.DELETED );
                if ( getLogger().isInfoEnabled() )
                {
                    getLogger().info( scmFile.toString() );
                }
                removedFiles.add( scmFile );
            }
        }
    }

    public List<ScmFile> getRemovedFiles()
    {
        return removedFiles;
    }
}
